@@ -77,6 +77,7 @@ class RobotSemTokenTypes(Enum):
     HEADER_SETTINGS = "headerSettings"
     HEADER_VARIABLE = "headerVariable"
     HEADER_TESTCASE = "headerTestcase"
+    HEADER_TASK = "headerTask"
     HEADER_COMMENT = "headerComment"
     HEADER_KEYWORD = "headerKeyword"
     TESTCASE_NAME = "testcaseName"
@@ -231,6 +232,15 @@ class RobotSemanticTokenProtocolPart(RobotLanguageServerProtocolPart, ModelHelpe
                     ): (RobotSemTokenTypes.CONFIG, None),
                 }
             )
+            definition.update(
+                {
+                    frozenset(
+                        {
+                            RobotToken.TASK_HEADER,
+                        }
+                    ): (RobotSemTokenTypes.HEADER_TASK, None),
+                }
+            )
 
         result: Dict[str, Tuple[Enum, Optional[Set[Enum]]]] = {}
         for k, v in definition.items():
